IsolatePool class
Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
dispose()
→ Future<void>
-
销毁线程池,正在执行的任务不一定会立即被销毁,当前任务执行完成后才会被销毁
-
init([int coreThreadSum = 4, bool isOpenLog = false])
→ Future<void>
-
isolate pool初始化,coreThreadSum 运行isolate数量,isOpenLog 是否打开日志
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
runTask<T>(Future<T> task())
→ Future<T>
-
寻找空闲线程执行任务,没有空闲线程将任务放入等待队列
-
toString()
→ String
-
A string representation of this object.
inherited